#
# spec file for package jsoncpp
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define sover   19
Name:           jsoncpp
Version:        1.8.4
Release:        lp151.2.3
Summary:        C++ library that allows manipulating with JSON
License:        MIT
Group:          Development/Libraries/C and C++
Url:            https://github.com/open-source-parsers/jsoncpp
Source0:        https://github.com/open-source-parsers/%{name}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  cmake >= 3.1
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig

%description
JSON is a lightweight data-interchange format. It can represent numbers,
strings, ordered sequences of values, and collections of name/value pairs.

JsonCpp is a C++ library that allows manipulating JSON values, including
serialization and deserialization to and from strings. It can also preserve
existing comment in unserialization/serialization steps, making it a convenient
format to store user input files.

%package devel
Summary:        Development files for %{name}
Group:          Development/Languages/C and C++
Requires:       lib%{name}%{sover} = %{version}

%description devel
JSON is a lightweight data-interchange format. It can represent numbers,
strings, ordered sequences of values, and collections of name/value pairs.

JsonCpp is a C++ library that allows manipulating JSON values, including
serialization and deserialization to and from strings. It can also preserve
existing comment in unserialization/serialization steps, making it a convenient
format to store user input files.

%package -n lib%{name}%{sover}
Summary:        Shared library for %{name}
Group:          System/Libraries

%description -n lib%{name}%{sover}
JSON is a lightweight data-interchange format. It can represent numbers,
strings, ordered sequences of values, and collections of name/value pairs.

JsonCpp is a C++ library that allows manipulating JSON values, including
serialization and deserialization to and from strings. It can also preserve
existing comment in unserialization/serialization steps, making it a convenient
format to store user input files.

%prep
%setup -q

%build
%cmake \
  -DBUILD_STATIC_LIBS=OFF \
  -DJSONCPP_WITH_CMAKE_PACKAGE=ON \
  -DJSONCPP_WITH_POST_BUILD_UNITTEST=OFF
%make_jobs

%install
%cmake_install

%check
# path needs to be exported otherwise unit tests will fail
export LD_LIBRARY_PATH=$LD_LIBRARY_PATH:%{buildroot}%{_libdir}
./build/src/test_lib_json/jsoncpp_test

%post -n lib%{name}%{sover} -p /sbin/ldconfig
%postun -n lib%{name}%{sover} -p /sbin/ldconfig

%files -n lib%{name}%{sover}
%doc LICENSE
%{_libdir}/lib%{name}.so.%{sover}*
%{_libdir}/lib%{name}.so.%{version}

%files devel
%doc AUTHORS LICENSE README.md
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/cmake/%{name}
%{_libdir}/lib%{name}.so
%{_includedir}/json/

%changelog
* Sat Dec 23 2017 avindra@opensuse.org
- Update to version 1.8.4:
  * Functional changes
  - Serialize UTF-8 string with Unicode escapes
    + Breaks code that relies on not Unicode-escaping encoding
    strings. A future release may allow skipping all Unicode
  escape.
  - Un-deprecate removeMember overloads, return void
  - Allow Json::Value to be used in a boolean context
  - Use move ctor in append()
  - Add value_type to improve integration with boost
  * Meta-changes
  - Fix meson.build to allow using jsoncpp as a subproject
  - Fix some compiler warnings
  - Update docs
* Mon Oct  2 2017 mpluskal@suse.com
- Update to version 1.8.3:
  * Also, fix writeCommentBeforeValue() iter deref
* Mon Aug 28 2017 mpluskal@suse.com
- Update to version 1.8.2:
  * Some C++ "move" operators.
  * Fix uninitialized value detected by valgrind.
  * Other minor improvements.
  * Moved most READ docs to Wiki.
* Tue Jul 11 2017 mpluskal@suse.com
- Update to version 1.8.1:
  * meson.build
  * Minor bug fixes and optimizations
  * Improved docs
* Mon Jan  2 2017 mpluskal@suse.com
- Update to version 1.8.0:
  * Build related changes, minimal required cmake is 3.1
- Execute tests in check section
* Fri Oct 14 2016 olaf@aepfle.de
- Require cmake 3.0.2 for make_jobs
* Fri Oct  7 2016 nmoudra@suse.com
- Update to vesrion 1.7.7:
  * At the suggestion of Peter Spiess-Knafl, we will bump the
    SOVERSION independent of the MAJOR.MINOR.MICRO version,
    in case we break binary compatibility.
- Changes for version 1.7.6:
  * Prevent possible SEGV. (Thanks to @ngg.)
  * Add RPATH for OSX libs. (Please let us know if this causes
    a problem.)
- Changes for version 1.7.5:
  * Fix locale for decimal points
    + Plus a fix for Android
  * int64_t for 64-bit integers
  * Optionally suppress space after comma
  * Avoid null for empty stringValue
  * Fix null ctor/dtor, using a "Meyers Singleton"
    + Thanks to @marklakata and @BillyDonahue in #488 in #490.
* Sat Jul 23 2016 mpluskal@suse.com
- Update to version 1.7.4:
  * Fix pkg-config
* Thu Jun 30 2016 mpluskal@suse.com
- Update to version 1.7.3:
  * Fix static initialization of null with Myers Singleton.
  * Fix other minor compiler and installation problems and
    warnings.
  * Fix amalgamated header.
- Drop -doc subpackage
* Sat Apr  2 2016 mpluskal@suse.com
- Update to 1.7.2
  * Fix a clang warning
* Wed Mar 23 2016 mpluskal@suse.com
- Update to 1.7.1
  * New precision setting in StreamBuilder
  * Move-semantics for some ctors
  * Added details to exception messages
  * Clarified when exceptions are thrown
  * Support isinfinite()
  * Secure memory-wiping allocator (via compilation flag, settable
    via cmake) For this, we changed all STL datatypes to macros,
    but all unchanged by default.
  * Lots of minor build-related improvements
    + Notably, cmake support for ccache
    + More supported systems
  * Note: 1.7.0 was recalled b/c it accidentally included
    SecureAlloc by default
* Tue Jul 28 2015 mpluskal@suse.com
- Update to 1.6.5
  * Other changes are just comments.
* Mon Apr 20 2015 mpluskal@suse.com
- Update to 1.6.2
  * Do not truncate output at embedded zeroes.
* Sat Apr  4 2015 mpluskal@suse.com
- Update to 1.6.1
  * Fix compilation error for snprintf() for some compilers.
- Update category for documentation
* Sun Mar 15 2015 mpluskal@suse.com
- Update to 1.6.0
  * Added Json::Exception, plus derived types:
    Json::RuntimeError
    Json::LogicError
  * Clarified when exceptions are thrown.
  * If you are trapping std::exception, nothing will change for you.
  * Fixed deprecation macro. (Thx to @Dani-Hub.)
  * Fixed compilation error for gcc-4.8. (Thx to @connormanning.)
  * Fixed CharReader::Factory base. (Thx to Tengiz Sharafiev.)
* Mon Mar  9 2015 mpluskal@suse.com
- Create and install cmake files
- Define libname to make maintenance easier
- Use graphviz-gd so that we can generate png files in
  documentation
- Update to 1.5.4
  * Support embedded 0s in strings (since UTF-8 allows them).
    + If you use c-string methods, or std::string::c_str(), you
    can still have problems.
    + Note that this support has a price: keys are now limited to
    1 billion characters (2^30).
  * Add feature to allow single-quotes in input JSON (since
    JavaScript allows them).
  * Propagate rarely-used StaticString thru copy-ctor.
  * Let JSON_ASSERT throw std::logic_error instead of
    std::runtime_error.
  * Skip Python tests by default, and run C++ unit-tests only for
    changes.
  * Ignore cmake-generated files for in-source builds.
  * Add tests. Fix other tests.
  * Remove unused code (JSON_VALUE_USE_INTERNAL_MAP).
  * Add rejectDupKeys feature.
    + Now part of strictMode.
  * Fix minor build issues for VisualStudio.
  * Fix compile error for VS2013, plus warnings.
  * Add operator[] to Builders.
  * In Builders, fix ::validate() (which was always returning
    true).
  * Fix UTF-8 zeroes bugs in previous patch-versions.
* Fri Mar  6 2015 mpluskal@suse.com
- Add missing dependency on graphviz
* Fri Mar  6 2015 mpluskal@suse.com
- Correct rpm group
- Update to 1.5.2
  * Fixed compile error for VS2013.
  * Added operator[] to Builders. (Builders are not yet widely
    used, and 0.9.z is very new, so we have not bumped the minor
    version number.)
- Changes for 1.5.1
  * Plus a minor bug-fix. (For the Builders, ::validate() was
    always returning true.)
* Tue Mar  3 2015 mpluskal@suse.com
- Update to 1.5.0
  * Support embedded 0s in strings (since UTF-8 allows them).
  * If you use c-string methods, or std::string::c_str(), you can
    still have problems.
  * Note that this support has a price: keys are now limited to
    1 billion characters (2^30).
  * Add feature to allow single-quotes in input JSON (since
    JavaScript allows them).
  * Propagate rarely-used StaticString thru copy-ctor.
  * Let JSON_ASSERT throw std::logic_error instead of
    std::runtime_error.
  * Fix VisualStudio warning.
  * Skip Python tests by default, and run C++ unit-tests only
    for changes.
  * Ignore cmake-generated files for in-source builds.
  * Add tests.
  * Remove unused code (JSON_VALUE_USE_INTERNAL_MAP).
* Tue Feb 24 2015 mpluskal@suse.com
- Update to 1.4.4
  * The odd allowDroppedNullPlaceholders feature of Readers
    (corresponding to dropNullPlaceholders in Writers) can be
    helpful when parsing javascript as JSON, when null elements
    have been discarded.
- Build doc package as noarch
* Tue Feb 17 2015 mpluskal@suse.com
- Update to 1.4.2:
  * minor cleanups
* Thu Feb  5 2015 mpluskal@suse.com
- Patch jsoncpp-1.0.0-lib_suffix.patch is longer necessary
- Update to version 1.4:
  * Updated the type system's behavior, in order to better support
    backwards compatibility with code that was written before
    64-bit integer support was introduced.
* Sat Dec 20 2014 mpluskal@suse.com
-  Update packace categories
* Fri Dec 12 2014 mpluskal@suse.com
- Enable cmake build
  + add fix for wrong lib_suffix - jsoncpp-1.0.0-lib_suffix.patch
- Disable building for i586 - jsonccp fails its unit tests
- Update to new release - 1.0.0:
  +  Updated the type system's behavior, in order to better support backwards
    compatibility with code that was written before 64-bit integer support was
    introduced.
  + Compilation
  - - New CMake based build system. Based in part on contribution from
    Igor Okulist and Damien Buhl (Patch #14).
  - - New header json/version.h now contains version number macros
    (JSONCPP_VERSION_MAJOR, JSONCPP_VERSION_MINOR, JSONCPP_VERSION_PATCH
    and JSONCPP_VERSION_HEXA).
* Fri Jul 25 2014 mvyskocil@opensuse.org
- Initial packaging of jsoncpp for openSUSE
